==> asposecellscloud-24.6.tar.gz: asposecellscloud-24.6/asposecellscloud/requests/put_worksheet_hyperlink_request.py <==
# coding: utf-8
"""
<copyright company="Aspose" file="PutWorksheetHyperlinkRequest.cs">
  Copyright (c) 2024 Aspose.Cells Cloud
</copyright>
<summary>
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all
 copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
</summary>
"""

import json

from six import iteritems
from asposecellscloud import *
from asposecellscloud.models import *
from asposecellscloud.requests import *
from six.moves.urllib.parse import quote

class PutWorksheetHyperlinkRequest(object):

    def __init__(self , name ,sheet_name ,first_row =None ,first_column =None ,total_rows =None ,total_columns =None ,address =None ,folder =None ,storage_name =None ):
        self.name = name 
        self.sheet_name = sheet_name 
        self.first_row = first_row 
        self.first_column = first_column 
        self.total_rows = total_rows 
        self.total_columns = total_columns 
        self.address = address 
        self.folder = folder 
        self.storage_name = storage_name 
    def create_http_request(self, api_client):

        # verify the required parameter 'name' is set
        if self.name is None:
            raise ValueError("Missing the required parameter `name` when calling `put_worksheet_hyperlink`")


        # verify the required parameter 'sheet_name' is set
        if self.sheet_name is None:
            raise ValueError("Missing the required parameter `sheet_name` when calling `put_worksheet_hyperlink`")


        # verify the required parameter 'first_row' is set
        if self.first_row is None:
            raise ValueError("Missing the required parameter `first_row` when calling `put_worksheet_hyperlink`")


        # verify the required parameter 'first_column' is set
        if self.first_column is None:
            raise ValueError("Missing the required parameter `first_column` when calling `put_worksheet_hyperlink`")


        # verify the required parameter 'total_rows' is set
        if self.total_rows is None:
            raise ValueError("Missing the required parameter `total_rows` when calling `put_worksheet_hyperlink`")


        # verify the required parameter 'total_columns' is set
        if self.total_columns is None:
            raise ValueError("Missing the required parameter `total_columns` when calling `put_worksheet_hyperlink`")


        # verify the required parameter 'address' is set
        if self.address is None:
            raise ValueError("Missing the required parameter `address` when calling `put_worksheet_hyperlink`")


        collection_formats = {}

        path_params = {}
        if self.name is not None:
            path_params['name'] = self.name
        if self.sheet_name is not None:
            path_params['sheetName'] = self.sheet_name
        query_params = []
        if self.first_row is not None:
            query_params.append(('firstRow',self.first_row ))
        if self.first_column is not None:
            query_params.append(('firstColumn',self.first_column ))
        if self.total_rows is not None:
            query_params.append(('totalRows',self.total_rows ))
        if self.total_columns is not None:
            query_params.append(('totalColumns',self.total_columns ))
        if self.address is not None:
            query_params.append(('address',self.address ))
        if self.folder is not None:
            query_params.append(('folder',self.folder ))
        if self.storage_name is not None:
            query_params.append(('storageName',self.storage_name ))

        header_params = {}

        form_params = []
        local_var_files = {}
        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = api_client.\
            select_header_content_type(['application/json'])


        # Authentication setting
        auth_settings = []
        resource_path = "/cells/{name}/worksheets/{sheetName}/hyperlinks"
        # path parameters
        if path_params:
            path_params = api_client.sanitize_for_serialization(path_params)
            path_params = api_client.parameters_to_tuples(path_params, collection_formats)
            for k, v in path_params:
                # specified safe chars, encode everything
                resource_path = resource_path.replace('{%s}' % k, quote(str(v), safe='/'))
        return {
                "method": "PUT",
                "path":resource_path,
                "query_params": query_params,
                "header_params": header_params,
                "form_params": form_params,
                "files":local_var_files,
                "auth_settings":auth_settings,
                "body": body_params,
                "collection_formats": collection_formats,
                "response_type": 'CellsCloudResponse'  
        }

==> asposecellscloud-25.5.tar.gz: asposecellscloud-25.5/asposecellscloud/requests/put_worksheet_hyperlink_request.py <==
# coding: utf-8
"""
<copyright company="Aspose" file="PutWorksheetHyperlinkRequest.cs">
  Copyright (c) 2025 Aspose.Cells Cloud
</copyright>
<summary>
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all
 copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
</summary>
"""

import json
import os

from six import iteritems
from asposecellscloud import *
from asposecellscloud.models import *
from asposecellscloud.requests import *
from six.moves.urllib.parse import quote

class PutWorksheetHyperlinkRequest(object):

    def __init__(self , name ,sheet_name ,first_row =None ,first_column =None ,total_rows =None ,total_columns =None ,address =None ,folder =None ,storage_name =None ):
        self.name = name 
        self.sheet_name = sheet_name 
        self.first_row = first_row 
        self.first_column = first_column 
        self.total_rows = total_rows 
        self.total_columns = total_columns 
        self.address = address 
        self.folder = folder 
        self.storage_name = storage_name 
    def create_http_request(self, api_client):

        # verify the required parameter 'name' is set
        if self.name is None:
            raise ValueError("Missing the required parameter `name` when calling `put_worksheet_hyperlink`")


        # verify the required parameter 'sheet_name' is set
        if self.sheet_name is None:
            raise ValueError("Missing the required parameter `sheet_name` when calling `put_worksheet_hyperlink`")


        # verify the required parameter 'first_row' is set
        if self.first_row is None:
            raise ValueError("Missing the required parameter `first_row` when calling `put_worksheet_hyperlink`")


        # verify the required parameter 'first_column' is set
        if self.first_column is None:
            raise ValueError("Missing the required parameter `first_column` when calling `put_worksheet_hyperlink`")


        # verify the required parameter 'total_rows' is set
        if self.total_rows is None:
            raise ValueError("Missing the required parameter `total_rows` when calling `put_worksheet_hyperlink`")


        # verify the required parameter 'total_columns' is set
        if self.total_columns is None:
            raise ValueError("Missing the required parameter `total_columns` when calling `put_worksheet_hyperlink`")


        # verify the required parameter 'address' is set
        if self.address is None:
            raise ValueError("Missing the required parameter `address` when calling `put_worksheet_hyperlink`")


        collection_formats = {}

        path_params = {}
        if self.name is not None:
            path_params['name'] = self.name
        if self.sheet_name is not None:
            path_params['sheetName'] = self.sheet_name
        query_params = []
        if self.first_row is not None:
            query_params.append(('firstRow',self.first_row ))
        if self.first_column is not None:
            query_params.append(('firstColumn',self.first_column ))
        if self.total_rows is not None:
            query_params.append(('totalRows',self.total_rows ))
        if self.total_columns is not None:
            query_params.append(('totalColumns',self.total_columns ))
        if self.address is not None:
            query_params.append(('address',self.address ))
        if self.folder is not None:
            query_params.append(('folder',self.folder ))
        if self.storage_name is not None:
            query_params.append(('storageName',self.storage_name ))

        header_params = {}
        header_params['x-aspose-client'] = 'python sdk';
        header_params['x-aspose-client-version'] = '25.5';

        form_params = []
        local_var_files = {}
        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = api_client.\
            select_header_content_type(['application/json'])


        # Authentication setting
        auth_settings = []
        resource_path =  "v3.0/cells/{name}/worksheets/{sheetName}/hyperlinks"
        # path parameters
        if path_params:
            path_params = api_client.sanitize_for_serialization(path_params)
            path_params = api_client.parameters_to_tuples(path_params, collection_formats)
            for k, v in path_params:
                # specified safe chars, encode everything
                resource_path = resource_path.replace('{%s}' % k, quote(str(v), safe='/'))
        return {
                "method": "PUT",
                "path":resource_path,
                "query_params": query_params,
                "header_params": header_params,
                "form_params": form_params,
                "files":local_var_files,
                "auth_settings":auth_settings,
                "body": body_params,
                "collection_formats": collection_formats,
                "response_type": 'CellsCloudResponse'  
        }
